from voicesynth.voicesynth import (
    Synthesizer, Model, show_available_models
)
from voicesynth.utils.config import (
    log_enable, version
)
from voicesynth.utils.__utils import (
    logging_enabled
)

__all__ = ["Synthesizer", "Model", "show_available_models"]







from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="voicesynth",
    version="0.0.5",
    author="ilyamiro",
    author_email="ilyamiro.workemail@gmail.com",
    description="Package for realistic voice synthesis",
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Development Status :: 3 - Alpha'
    ],
    install_requires=[
        "torch",
        "rich",
        "pygobject",
        "playsound",
        "numpy"
    ]

)
